<template>
    <common-dialog
        fullscreen
        title="模型配置"
        class="step-dialog"
        :visible="dialogVisible"
        :before-close="beforeCloseDialog"
        destroy-on-close
    >
        <el-steps
            :active="activeStep"
            process-status="finish"
            finish-status="success"
            simple
            class="step-container"
        >
            <el-step title="模型信息" icon="el-icon-notebook-2"></el-step>
            <el-step title="关联机组" icon="el-icon-connection"></el-step>
            <el-step title="配置入参" icon="el-icon-upload2"></el-step>
            <el-step title="配置出参" icon="el-icon-download"></el-step>
            <el-step
                title="配置模型任务"
                icon="el-icon-c-scale-to-original"
            ></el-step>
        </el-steps>

        <model-info
            v-if="activeStep == 0"
            @saveModel="getModelId"
            @importModel="importModel"
            :modelObj="modelObj"
        ></model-info>
        <model-fan
            v-else-if="activeStep == 1"
            :needHeader="false"
            :modelObj="modelObj"
            class="inner-step"
            ref="modelFan"
        ></model-fan>
        <param-in-config
            v-else-if="activeStep == 2"
            :needHeader="false"
            :modelObj="modelObj"
            @taosIsCreate="taosIsCreate"
            class="inner-step"
        ></param-in-config>
        <param-out-config
            v-else-if="activeStep == 3"
            :needHeader="false"
            :modelObj="modelObj"
            @resultIsCreate="resultIsCreate"
            class="inner-step"
        ></param-out-config>
        <model-task
            v-else-if="activeStep == 4"
            :needHeader="false"
            :modelObj="modelObj"
            class="inner-step"
        ></model-task>
        <div slot="footer" style="text-align: center">
            <el-button type="primary" @click="prevStep" v-if="activeStep > 0"
                >上一步</el-button
            >
            <el-button
                type="primary"
                :disabled="modelId ? false : true"
                @click="nextStep"
                v-if="activeStep < 4"
                >下一步</el-button
            >
            <el-button @click="beforeCloseDialog">关闭</el-button>
        </div>
    </common-dialog>
</template>

<script>
import modelInfo from '@/views/Basic/modules/modelInfo'
import ModelFan from '@/views/Basic/modules/ModelFan'
import ParamInConfig from '@/views/Basic/modules/ParamInConfig'
import ParamOutConfig from '@/views/Basic/modules/ParamOutConfig'
import ModelTask from '@/views/Basic/modules/ModelTask'
export default {
    name: 'modelStepDialog',
    components: {
        modelInfo,
        ModelFan,
        ParamInConfig,
        ParamOutConfig,
        ModelTask,
    },
    data() {
        return {
            dialogVisible: false,
            activeStep: 0,
            modelId: '',
            modelObj: null,
            requiredKey: {
                importModel: true,
                modelFan: false,
                paramsIn: false,
                paramsOut: false,
            },
        }
    },
    created() {},
    methods: {
        open() {
            // todo 测试id 测试结束删除 ---start
            // this.getModelId('1516973284275654656')
            // todo 测试id 测试结束删除 ---end
            this.dialogVisible = true
        },
        prevStep() {
            if (this.activeStep < 1) {
                return
            }
            this.activeStep--
        },
        nextStep() {
            if (this.activeStep >= 4) {
                return
            }
            if (this.activeStep == 0) {
                // 模型信息 需要算法文件才可走到下一步
                if (!this.requiredKey.importModel) {
                    this.$message({
                        type: 'warning',
                        message: '请上传算法文件！',
                    })
                    return
                }
            }
            if (this.activeStep == 1) {
                // 记录关联机组是否有数据  
                this.$nextTick(()=>{
                    this.requiredKey.modelFan = this.$refs.modelFan.data.length >= 1
                })
            }
            if (this.activeStep == 2) {
                // 提示没有采集表
                if(this.requiredKey.paramsIn == false){
                    this.$message({
                        type: 'warning',
                        message: '请创建采集表！',
                    })
                }
            }
            if (this.activeStep == 3) {
                if (!this.requiredKey.importModel) {
                    this.$message({
                        type: 'warning',
                        message: '请上传算法文件！',
                    })
                    return
                } else if (!this.requiredKey.modelFan) {
                    this.$message({
                        type: 'warning',
                        message: '请配置关联机组！',
                    })
                    return
                } else if (!this.requiredKey.paramsIn) {
                    this.$message({
                        type: 'warning',
                        message: '请配置入参和采集表！',
                    })
                    return
                } else if (!this.requiredKey.paramsOut) {
                    this.$message({
                        type: 'warning',
                        message: '请配置出参和结果表！',
                    })
                    return
                }
            }
            this.activeStep++
        },
        beforeCloseDialog() {
            this.activeStep = 0
            this.dialogVisible = false
            this.modelObj = null
            this.modelId = '',
            this.requiredKey = {
                importModel: false,
                modelFan: false,
                paramsIn: false,
                paramsOut: false,
            }
            this.$emit('reloadTable')
        },
        getModelId(id) {
            this.modelId = id
            this.$http
                .get('${cssc}/biz/model/modelInfo/v1/' + this.modelId)
                .then((resp) => {
                    this.modelObj = resp.data
                    if(this.modelObj.modelType == 'BuiltIn'){
                        this.requiredKey.importModel = true
                    }
                })
        },
        importModel(){
            this.requiredKey.importModel = true
        },
        taosIsCreate(){
            this.requiredKey.paramsIn = true
        },
        resultIsCreate(){
            this.requiredKey.paramsOut = true
        }
    },
}
</script>

<style lang="scss" scoped>
.step-dialog /deep/ .el-dialog > .el-dialog__body {
    height: calc(100vh - 124px);
    padding: 10px 20px;
    overflow: auto;
}
.step-dialog /deep/ .el-steps--simple {
    padding: 10px 6%;
}
.step-container{
    margin-bottom: 20px;
}
.inner-step{
    height: calc(100% - 70px)!important;
}

</style>